.\" toc-example-1.ms: vim: filetype=groff
.\"
.\" Simple example of linked TOC in PDF,
.\" *without* accompanying outline.
.\"
.\" Format with:
.\"   touch toc.import
.\"   pdfroff -U -mspdf --no-toc-relocation toc-example-1.ms \
.\"      > toc-example-1.pdf
.
.\" ========================================
.\"  Markup for front matter would go here.
.\" ========================================
.
.\" Set margins for the TOC page.
.
.nr PO  3.0c
.nr LL 15.0c
.
.\" Emit the TOC page heading...
.\" In this instance, this also initialises ms state.
.
.SH 1
.ce 1
Table of Contents
.sp 2c
.
.\" Tabstop settings must come *after* ms initialisation;
.\" the first is where the TOC entry leader ends; the second
.\" provides right justification for the page numbers.
.
.ta \n[LL]u-1.0c \n[LL]uR
.
.de XH
.\" A macro for specifying headings with linked TOC entries...
.\"
.\" Inputs:
.\"   $1 = S for SH headings; N for NH
.\"   $2 = heading level; (e.g. .NH 2, for $2 = 2)
.\"   $3 = initial text of heading; (propagates to TOC)
.\"
.\" Returns:
.\"   \*[PDFHREF.XH.NAME] = PDF reference label @ heading location
.\"
.   \\$1H \\$2
.   ds PDFHREF.XH.NAME  toc.tag\\n+[toc.reference.count]
.   write toc .pdfhref L -D \\*[PDFHREF.XH.NAME] -- "\\$3\0\0\\\\a\\\\t\\n%"
.   pdfhref M -N \\*[PDFHREF.XH.NAME]
.   nop \\$3
..
.\" Merge dynamically generated markup, to lay out the TOC
.
.so toc.import
.
.\" Reinitialise the TOC markup file, and reference counter,
.\" to begin capture of freshly updated TOC layout markup.
.
.open toc toc.import
.nr toc.reference.count 0 1
.
.\" Reset page margins and tabstops for body of document,
.\" and advance to new page, to begin formatting it.
.
.nr PO  2.0c
.nr LL 17.0c
.ta
.bp
.
.\" ===========================
.\"  Document Body Begins Here
.\" ===========================
.
.XH S 1 Introduction
.LP
This is a trivial example of a heading,
with a live table of contents reference.
This example does not associate document outline entries
with the table of contents entries.
.
.LP
Notice that,
in this example,
the TOC reference counter has been incremented to \n[toc.reference.count],
representing the total number of table of contents entries added.
.
.\" May not be strictly necessary...
.\" but for completeness, we close the TOC markup capture file.
.
.close toc
.
.\" toc-example-1.ms: end of file
